# skydl
high efficiency deep learning framework

# add skydl quickly
pip install skydl (or: pip install --no-deps skydl)

# how to use skydl
```
>>> import skydl
>>> skydl.__version__
```

# how to setup
$python setup.py install or $python3 setup.py sdist bdist_wheel --universal , it will create folder: build, dist, egg-info
